MarkerWidget class

Inheritance

Constructors

MarkerWidget({Key? key, required Marker data, required bool isFirst, required bool isLast, required TimelineProperties properties})
Creates a new MarkerWidget.

Properties

data Marker
The marker data containing content and configuration.
final
hashCode int
The hash code for this object.
no setterinherited
isFirst bool
Whether this marker is the first one in the timeline.
final
isLast bool
Whether this marker is the last one in the timeline.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
properties TimelineProperties
Timeline-specific properties that affect the marker's appearance.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
childWidget(BoxConstraints constraints) Widget
Builds the marker's main content widget with appropriate constraints.
content(BuildContext context, BoxConstraints constraints) Widget
Builds the content layout of the marker.
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
iconWidget() Widget
Builds the marker's icon widget.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited