iconWidget method

Widget iconWidget()

Builds the marker's icon widget.

If no custom icon is provided in the marker data, creates a default circular dot using the timeline's line color.

Implementation

Widget iconWidget() => SizedBox(
    width: properties.iconSize,
    height: properties.iconSize,
    child: data.icon ??
        Container(
            width: properties.lineWidth * 2,
            height: properties.lineWidth * 2,
            decoration: BoxDecoration(
                color: properties.lineColor, shape: BoxShape.circle)));