iconAlignment property
How the marker's icon should be aligned relative to its content.
Implementation
final MarkerIconAlignment iconAlignment;
How the marker's icon should be aligned relative to its content.
final MarkerIconAlignment iconAlignment;