properties property
Properties that define the default visual appearance of the timeline.
Implementation
final TimelineProperties properties;
Properties that define the default visual appearance of the timeline.
final TimelineProperties properties;